Satunpay widget

Features

With this package you can deposit and withdraw

Usage

just use deposit and widget below to start deposit process sh deposit

           SaturnPay(
              paymentType: 'deposit',
              fullname: 'Saturn',
              amount: '400000.0',
              emailaddress: 'telesphore@saturnfi.co',
              partnerID: 'saturn',
              phonenumber: '3222222234',
              usdtwallet: 'TXZwwwdjddkdkkdkdkdkdkkdd',
            ),

--> sh withdraw Process For withdraw use the below widget changes the parameters--> PartnerID need to be provided by saturnfi

          SaturnPay(
              paymentType: 'withdraw',
              fullname: 'chance',
              usdtamount: '400',
              bankname: 'BK ',
              accountnumber: '3443535355',
              phonenumber: '3222222234',
              emailaddress: 'telesphore@saturnfi.co',
              partnerID: 'saturn',
              accountname: 'Chance Teles',
            ),