DepositController class
Inheritance
Object
GetLifeCycle
DisposableInterface
GetxController
DepositController
Implemented types
Properties
agentAccountNumber
↔ RxString
getter/setter pair
agentFullname
↔ RxString
getter/setter pair
agentID
↔ RxString
getter/setter pair
amountAfterCharge
↔ RxString
getter/setter pair
bankName
↔ RxString
getter/setter pair
email
↔ RxString
getter/setter pair
exchangeRate
↔ RxString
getter/setter pair
fullName
↔ RxString
getter/setter pair
hashCode
→ int
The hash code for this object.
no setter inherited
hasListeners
→ bool
no setter inherited
initialized
→ bool
Checks whether the controller has already been initialized.
no setter inherited
isClosed
→ bool
Checks whether the controller has already been closed.
no setter inherited
listeners
→ int
no setter inherited
loading
↔ RxBool
getter/setter pair
nairaAmount
↔ RxString
getter/setter pair
nairaAmountkobo
↔ RxString
getter/setter pair
narration
↔ RxString
getter/setter pair
onDelete
→ InternalFinalCallback<void >
Internal callback that starts the cycle of this controller.
final inherited
onStart
→ InternalFinalCallback<void >
Called at the exact moment the widget is allocated in memory.
It uses an internal "callable" type, to avoid any @overrides in subclases.
This method should be internal and is required to define the
lifetime cycle of the subclass.
final inherited
partnerid
↔ RxString
getter/setter pair
paymentStatus
↔ RxString
getter/setter pair
phoneNumber
↔ RxString
getter/setter pair
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
usdtAmount
↔ RxString
getter/setter pair
usdtwalletAddress
↔ RxString
getter/setter pair
userId
↔ RxString
getter/setter pair
Methods
$configureLifeCycle ()
→ void
inherited
addListener (GetStateUpdate listener )
→ Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId (Object ? key , GetStateUpdate listener )
→ Disposer
inherited
agentWithBalance ()
→ void
dispose ()
→ void
inherited
disposeId (Object id )
→ void
To dispose an id from future updates(), this ids are registered
by GetBuilder() or similar, so is a way to unlink the state change with
the Widget from the Controller.
inherited
getExchaangeRate ({String ? amount , String ? fullname , String ? phonenumber , String ? emailaddress , String ? usdtwallet , String ? partnerID })
→ dynamic
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyChildrens ()
→ void
inherited
onClose ()
→ void
Called before onDelete method. onClose might be used to
dispose resources used by the controller. Like closing events,
or streams before the controller is destroyed.
Or dispose objects that can potentially create some memory leaks,
like TextEditingControllers, AnimationControllers.
Might be useful as well to persist some data on disk.
inherited
onInit ()
→ void
Called immediately after the widget is allocated in memory.
You might use this to initialize something for the controller.
override
onReady ()
→ void
Called 1 frame after onInit(). It is the perfect place to enter
navigation events, like snackbar, dialogs, or a new route, or
async request.
inherited
paymentVerification ()
→ void
refresh ()
→ void
inherited
refreshGroup (Object id )
→ void
inherited
removeListener (VoidCallback listener )
→ void
Remove a previously registered closure from the list of closures that the
object notifies.
inherited
removeListenerId (Object id , VoidCallback listener )
→ void
inherited
sendPayment ()
→ void
startDeposit ()
→ void
toString ()
→ String
A string representation of this object.
inherited
update ([List <Object > ? ids , bool condition = true ])
→ void
Rebuilds GetBuilder each time you call update();
Can take a List of ids, that will only update the matching
GetBuilder( id: ),
ids can be reused among GetBuilders like group tags.
The update will only notify the Widgets, if condition is true.
inherited
verifyPayment ()
→ void