CallApi class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
url
→ String
-
final
Methods
-
getData(dynamic endpoint)
→ dynamic
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
postData(dynamic data, dynamic apiUrl)
→ dynamic
-
-
putData(dynamic data, dynamic apiUrl)
→ dynamic
-
-
toString()
→ String
-
A string representation of this object.
inherited